RenderingDeviceImpl

Struct RenderingDeviceImpl 

pub struct RenderingDeviceImpl {
Show 15 fields pub raw: Device, pub shared: Arc<SharedDevice>, pub phy_device: PhysicalDevice, pub properties: PhysicalDeviceProperties, pub mem_properties: PhysicalDeviceMemoryProperties, pub features: Features, pub enabled_extensions: Vec<&'static CStr>, pub enabled_layers: Vec<&'static CStr>, pub enabled_instance_exts: Vec<&'static CStr>, pub queue_families: QueueFamilies, pub main_queue: Queue, pub present_queue: Queue, pub device_mutex: RawMutex, pub frames: Vec<Mutex<Frame>>, pub frame_counter: RwLock<(u64, usize)>, /* private fields */
}
The inner state of a Vulkan rendering device containing the instance, physical device, logical device, and other core resources.

Fields

raw: Deviceshared: Arc<SharedDevice>phy_device: PhysicalDeviceproperties: PhysicalDevicePropertiesmem_properties: PhysicalDeviceMemoryPropertiesfeatures: Featuresenabled_extensions: Vec<&'static CStr>enabled_layers: Vec<&'static CStr>enabled_instance_exts: Vec<&'static CStr>queue_families: QueueFamiliesmain_queue: Queuepresent_queue: Queuedevice_mutex: RawMutexframes: Vec<Mutex<Frame>>frame_counter: RwLock<(u64, usize)>